##############
How-To Guides
##############

These guides provide a step-by-step guide for performing specific
tasks. In contrast with tutorials, these guides assume a basic level
of understanding of topics like Haven, Ophyd, Ophyd-async, and
Bluesky.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   adding_devices.rst
